Package: vice
Version: 3.0.0.dfsg-2
Severity: normal
Tags: patch

Dear Maintainer,

When a local administrator wishes to install the VICE ROMs for all
users on the local machine, the usual and recommended practice would
be to put them under /usr/local/. 

VICE does not look there by default, however, which forces local
admins to put the files in /usr/lib/, a directory normally reserved
for the OS. Only Debian's version of VICE should be writing files
there, not local admins.

The solution is to modify VICE to add /usr/local to the search path. I
have included a patch below.

--- src/arch/unix/archdep.c.orig        2016-10-20 10:07:43.000000000 -0700
+++ src/arch/unix/archdep.c     2019-03-31 10:51:21.530798424 -0700
@@ -169,8 +169,8 @@
         boot_path = archdep_boot_path();
         home_path = archdep_home_path();
 
-        /* First search in the `LIBDIR' then the $HOME/.vice/ dir (home_path)
-           and then in the `boot_path'.  */
+        /* First search in the `LIBDIR', then /usr/local/vice, then the home 
dir
+          ($HOME/.vice/), and finally in the `boot_path'.  */
 
 #if defined(MINIXVMD) || defined(MINIX_SUPPORT)
         default_path_temp = util_concat(LIBDIR, "/", emu_id, 
ARCHDEP_FINDPATH_SEPARATOR_STRING,
@@ -207,12 +207,18 @@
                                    home_path, "/", VICEUSERDIR, "/PRINTER", 
NULL);
 #else
         default_path = util_concat(LIBDIR, "/", emu_id, 
ARCHDEP_FINDPATH_SEPARATOR_STRING,
+                                  "/usr/local/vice/", emu_id, 
ARCHDEP_FINDPATH_SEPARATOR_STRING,
+                                  "/usr/local/lib/vice/", emu_id, 
ARCHDEP_FINDPATH_SEPARATOR_STRING,
                                    home_path, "/", VICEUSERDIR, "/", emu_id, 
ARCHDEP_FINDPATH_SEPARATOR_STRING,
                                    boot_path, "/", emu_id, 
ARCHDEP_FINDPATH_SEPARATOR_STRING,
                                    LIBDIR, "/DRIVES", 
ARCHDEP_FINDPATH_SEPARATOR_STRING,
+                                  "/usr/local/vice/DRIVES", emu_id, 
ARCHDEP_FINDPATH_SEPARATOR_STRING,
+                                  "/usr/local/lib/vice/DRIVES", emu_id, 
ARCHDEP_FINDPATH_SEPARATOR_STRING,
                                    home_path, "/", VICEUSERDIR, "/DRIVES", 
ARCHDEP_FINDPATH_SEPARATOR_STRING,
                                    boot_path, "/DRIVES", 
ARCHDEP_FINDPATH_SEPARATOR_STRING,
                                    LIBDIR, "/PRINTER", 
ARCHDEP_FINDPATH_SEPARATOR_STRING,
+                                  "/usr/local/vice/PRINTER", emu_id, 
ARCHDEP_FINDPATH_SEPARATOR_STRING,
+                                  "/usr/local/lib/vice/PRINTER", emu_id, 
ARCHDEP_FINDPATH_SEPARATOR_STRING,
                                    home_path, "/", VICEUSERDIR, "/PRINTER", 
ARCHDEP_FINDPATH_SEPARATOR_STRING,
                                    boot_path, "/PRINTER", NULL);
 #endif




-- System Information:
Debian Release: 9.8
  APT prefers stable-updates
  APT policy: (500, 'stable-updates'), (500, 'stable')
Architecture: amd64 (x86_64)
Foreign Architectures: i386

Kernel: Linux 4.9.0-8-amd64 (SMP w/4 CPU cores)
Locale: LANG=en_US.UTF-8, LC_CTYPE=en_US.UTF-8 (charmap=UTF-8), 
LANGUAGE=en_US.UTF-8 (charmap=UTF-8)
Shell: /bin/sh linked to /bin/dash
Init: systemd (via /run/systemd/system)

Versions of packages vice depends on:
ii  dpkg                 1.18.25
ii  install-info         6.3.0.dfsg.1-1+b2
ii  libasound2           1.1.3-5
ii  libatk1.0-0          2.22.0-1
ii  libc6                2.24-11+deb9u4
ii  libcairo-gobject2    1.14.8-1
ii  libcairo2            1.14.8-1
ii  libgcc1              1:6.3.0-18+deb9u1
ii  libgdk-pixbuf2.0-0   2.36.5-2+deb9u2
ii  libglib2.0-0         2.50.3-2
ii  libgnutls30          3.5.8-5+deb9u4
ii  libgtk-3-0           3.22.11-1
ii  libieee1284-3        0.2.11-13
ii  libjpeg62-turbo      1:1.5.1-2
ii  libpango-1.0-0       1.40.5-1
ii  libpangocairo-1.0-0  1.40.5-1
ii  libpcre2-8-0         10.32-4
ii  libpng16-16          1.6.28-1
ii  libpulse0            10.0-1+deb9u1
ii  libreadline7         7.0-3
ii  libstdc++6           6.3.0-18+deb9u1
ii  libvte-2.91-0        0.46.1-1
ii  libx11-6             2:1.6.4-3+deb9u1
ii  libxrandr2           2:1.5.1-1
ii  libxxf86vm1          1:1.1.4-1+b2
ii  zlib1g               1:1.2.8.dfsg-5

vice recommends no packages.

vice suggests no packages.

-- no debconf information

Reply via email to